@@ -1,6 +1,6 @@
 TMP_DIR = "/tmp/touchandgo"
 DEBUG = True
 
-DOWNLOAD_LIMIT = 10240
+DOWNLOAD_LIMIT = 40960#10240
 DEFAULT_PORT = 8888
 WAIT_FOR_IT = 0.3
